PPTerm

Struct PPTerm 

pub struct PPTerm { /* private fields */ }

Implementations

Source

impl PPTerm

pub fn new<L: Into<Option<&'static str>>>( x: i32, y: i32, w: i32, h: i32, label: L, ) -> Self

Create a new canvas terminal with default dimensions (80x24).

pub fn new_with_dims<L: Into<Option<&'static str>>>( x: i32, y: i32, w: i32, h: i32, label: L, cols: u16, rows: u16, ) -> Self

Create a new canvas terminal with explicit terminal dimensions (cols x rows).

pub fn with_dimensions(cols: u16, rows: u16) -> Self

Convenience: construct with only (cols, rows). Position/size can be set later via standard FLTK WidgetExt methods like size_of_parent().

pub fn with_dimensions_and_scrollback( cols: u16, rows: u16, scrollback_lines: usize, ) -> Self

Convenience: construct with (cols, rows, scrollback_lines).

pub fn new_deferred<L: Into<Option<&'static str>>>( x: i32, y: i32, w: i32, h: i32, label: L, ) -> Self

Construct without starting the PTY; call start() after the window has been shown and sized for correct initial geometry.

Examples found in repository?
examples/ex1.rs (line 8)
4fn main() {
5    let a = app::App::default();
6    let mut w = window::Window::default().with_size(600, 400);
7    // Defer PTY start until after window sizing
8    let mut term = PPTerm::new_deferred(0, 0, 0, 0, None).size_of_parent();
9    w.end();
10    w.show();
11
12    // Start the PTY with correct initial cols/rows
13    term.start();
14
15    // Test the original command that should show red text
16    term
17        .write_all(b"echo -e \"\x1b[1;31mHELLO\"\n")
18        .unwrap();
19
20    a.run().unwrap();
21}
pub fn new_with_dims_deferred<L: Into<Option<&'static str>>>( x: i32, y: i32, w: i32, h: i32, label: L, cols: u16, rows: u16, ) -> Self

Construct with explicit dimensions but defer PTY start until start().

pub fn with_dimensions_deferred(cols: u16, rows: u16) -> Self

Convenience deferred constructors

pub fn with_dimensions_and_scrollback_deferred( cols: u16, rows: u16, scrollback_lines: usize, ) -> Self

pub fn start(&mut self)

Start the underlying PTY if it hasn’t been started. Compute grid from the current widget size so the shell starts at the correct width.

Examples found in repository?
examples/ex1.rs (line 13)
4fn main() {
5    let a = app::App::default();
6    let mut w = window::Window::default().with_size(600, 400);
7    // Defer PTY start until after window sizing
8    let mut term = PPTerm::new_deferred(0, 0, 0, 0, None).size_of_parent();
9    w.end();
10    w.show();
11
12    // Start the PTY with correct initial cols/rows
13    term.start();
14
15    // Test the original command that should show red text
16    term
17        .write_all(b"echo -e \"\x1b[1;31mHELLO\"\n")
18        .unwrap();
19
20    a.run().unwrap();
21}
pub fn widget(&self) -> &Scroll

pub fn redraw(&mut self)

pub fn buffer(&self) -> Arc<Mutex<CellBuffer>>

pub fn shutdown(&self)

pub fn set_auto_follow(&mut self, enabled: bool)

pub fn auto_follow_handle(&self) -> Arc<Mutex<bool>>

pub fn cols(&self) -> u16

Current column count reported by the widget.

pub fn rows(&self) -> u16

Current row count reported by the widget.

pub fn write_all(&self, s: &[u8]) -> Result<(), Error>

Write raw bytes to the underlying PTY.

Examples found in repository?
examples/ex1.rs (line 17)
4fn main() {
5    let a = app::App::default();
6    let mut w = window::Window::default().with_size(600, 400);
7    // Defer PTY start until after window sizing
8    let mut term = PPTerm::new_deferred(0, 0, 0, 0, None).size_of_parent();
9    w.end();
10    w.show();
11
12    // Start the PTY with correct initial cols/rows
13    term.start();
14
15    // Test the original command that should show red text
16    term
17        .write_all(b"echo -e \"\x1b[1;31mHELLO\"\n")
18        .unwrap();
19
20    a.run().unwrap();
21}
pub fn set_dims(&mut self, cols: u16, rows: u16) -> Result<(), Box<dyn Error>>

Manually set terminal cell dimensions (cols x rows) and resize the PTY. Note: the periodic layout updater will continue to sync PTY size to the current widget size; this method is most useful for initial sizing or when external code coordinates widget resizing alongside PTY resize.

Source

impl PPTerm

pub fn with_pos(self, x: i32, y: i32) -> Self

Initialize to position x, y

pub fn with_size(self, width: i32, height: i32) -> Self

Initialize to size width, height

pub fn with_label(self, title: &str) -> Self

Initialize with a label

pub fn with_align(self, align: Align) -> Self

Initialize with alignment

pub fn with_type<T: WidgetType>(self, typ: T) -> Self

Initialize with type

pub fn below_of<W: WidgetExt>(self, wid: &W, padding: i32) -> Self

Initialize at bottom of another widget

pub fn above_of<W: WidgetExt>(self, wid: &W, padding: i32) -> Self

Initialize above of another widget

pub fn right_of<W: WidgetExt>(self, wid: &W, padding: i32) -> Self

Initialize right of another widget

pub fn left_of<W: WidgetExt>(self, wid: &W, padding: i32) -> Self

Initialize left of another widget

pub fn center_of<W: WidgetExt>(self, w: &W) -> Self

Initialize center of another widget

pub fn center_x<W: WidgetExt>(self, w: &W) -> Self

Initialize center of another widget on the x axis

pub fn center_y<W: WidgetExt>(self, w: &W) -> Self

Initialize center of another widget on the y axis

pub fn center_of_parent(self) -> Self

Initialize center of parent

pub fn size_of<W: WidgetExt>(self, w: &W) -> Self

Initialize to the size of another widget

pub fn size_of_parent(self) -> Self

Initialize to the size of the parent

Examples found in repository?
examples/ex1.rs (line 8)
4fn main() {
5    let a = app::App::default();
6    let mut w = window::Window::default().with_size(600, 400);
7    // Defer PTY start until after window sizing
8    let mut term = PPTerm::new_deferred(0, 0, 0, 0, None).size_of_parent();
9    w.end();
10    w.show();
11
12    // Start the PTY with correct initial cols/rows
13    term.start();
14
15    // Test the original command that should show red text
16    term
17        .write_all(b"echo -e \"\x1b[1;31mHELLO\"\n")
18        .unwrap();
19
20    a.run().unwrap();
21}

Methods from Deref<Target = Scroll>

pub fn scrollbar(&self) -> Scrollbar

Returns the vertical scrollbar

pub fn hscrollbar(&self) -> Scrollbar

Returns the horizontal scrollbar

pub fn xposition(&self) -> i32

Returns the x position

pub fn yposition(&self) -> i32

Returns the y position

pub fn scroll_to(&mut self, x: i32, y: i32)

Scrolls to x and y

pub fn scrollbar_size(&self) -> i32

Gets the scrollbar size

pub fn set_scrollbar_size(&mut self, new_size: i32)

Sets the scrollbar size

pub fn auto_layout(&mut self)

Auto layout a scroll widget